---
name: 🐛 Bug report
about: Filling a bug report
title: ''
labels: bug
assignees: ''

---

- [ ] I have updated Purchases SDK to the latest version
- [ ] I have read the [Contribution Guidelines](../blob/main/CONTRIBUTING.md)
- [ ] I have searched the [Community](https://community.revenuecat.com)
- [ ] I have read [docs.revenuecat.com](https://docs.revenuecat.com/)
- [ ] I have searched for [existing Github issues](../issues)

**Describe the bug**
A clear and concise description of what the bug is. The more detail you can provide the faster our team will be able to triage and resolve the issue. **Do not remove any of the steps from the template below. If a step is not applicable to your issue, please leave that step empty.**

1. Environment
   1. Platform:
   2. SDK version:
   3. OS version:
   4. Device and/or simulator:
      - [ ] Device
      - [ ] Simulator
   5. Environment:
      - [ ] Sandbox
      - [ ] Production
   6. How widespread is the issue. Percentage of devices affected.
2. [Debug logs](https://docs.revenuecat.com/docs/debugging) that reproduce the issue. **Complete logs with `Purchases.logLevel = .verbose` will help us debug this issue.**

```
Logs here
```

3. Steps to reproduce, with a description of expected vs. actual behavior

_Please fill in_
 
4. **Other information** (e.g. stacktraces, related issues, suggestions how to fix, links for us to have context, eg. stackoverflow, etc.)

5. **Additional context**
Add any other context about the problem here.
